part of masamune;

class PlatformBuilder extends StatelessWidget {
  const PlatformBuilder({
    this.mobile,
    this.desktop,
    this.thresholdWidth = 768,
    this.defaultWidget = const Empty(),
  }) : assert(
          mobile != null || desktop != null,
          "You need to specify either [mobile] or [desktop].",
        );

  final double thresholdWidth;
  final Widget? Function()? mobile;
  final Widget? Function()? desktop;
  final Widget defaultWidget;

  @override
  Widget build(BuildContext context) {
    if (isMobile(context)) {
      return mobile?.call() ?? desktop?.call() ?? defaultWidget;
    } else {
      return desktop?.call() ?? mobile?.call() ?? defaultWidget;
    }
  }
}

class PlatformScrollbar extends StatelessWidget {
  const PlatformScrollbar({required this.child});

  final Widget child;
  @override
  Widget build(BuildContext context) {
    if (isMobile(context)) {
      return child;
    } else {
      return Scrollbar(
        isAlwaysShown: true,
        child: child,
      );
    }
  }
}

bool isMobile(
  BuildContext context, {
  double thresholdWidth = 768,
}) {
  if (Config.isAndroid || Config.isIOS) {
    return true;
  }
  final width = context.mediaQuery.size.width;
  if (width < thresholdWidth) {
    return true;
  }
  return false;
}
